Presentation
===

Python Library for Electromagnetic physics applied to subsurface radars

Installation
===

`pip install subradar`

Keywords
===

Most of the modules accept the following keywords with SI units


| Keyword | Definition |
|---|---|
| bmw | Beamwidth angle |
| cl | Correlation length |
| ep | Dielectric permittivity |
| h | Altitude |
| mp | Magnetic permeability |
| nRCS | Normalized Radar Cross Section |
| RCS | Radar Cross Section |
| n | Optical index |
| R | Reflection coefficient |
| sigma_h, sh | Root Mean Square height |
| theta, th | angle |
| T | Transmission coefficient |
| wf | Wave frequency |
| wb | Bandwidth |
| wk | Wave number |
| wl | Wavelength |
